@@ -22,22 +22,26 @@ jar_file_path = os.path.normpath(os.path.join(
               type=click.Choice(['jar', 'docker']),
               default='jar'
               )
-def commit(source, executable):
+@click.option('--max-days',
+              help="the maximum number of days to collect commits retroactively",
+              default=30
+              )
+def commit(source, executable, max_days):
     source = os.path.abspath(source)
 
     if executable == 'jar':
         try:
-            exec_jar(source)
+            exec_jar(source, max_days)
         except Exception as e:
             if os.getenv(REPORT_ERROR_KEY):
                 raise e
             else:
                 print(e)
     elif executable == 'docker':
-        exec_docker(source)
+        exec_docker(source, max_days)
 
 
-def exec_jar(source):
+def exec_jar(source, max_days):
     java = get_java_command()
 
     if not java:
@@ -49,8 +53,8 @@ def exec_jar(source):
     proxy_option = _build_proxy_option(https_proxy) if https_proxy else ""
 
     os.system(
-        "{} {} -jar {} ingest:commit -endpoint {} {}"
-        .format(java, proxy_option, jar_file_path, "{}/intake/".format(base_url), source))
+        "{} {} -jar {} ingest:commit -endpoint {} -max-days {} {}"
+        .format(java, proxy_option, jar_file_path, "{}/intake/".format(base_url), max_days, source))
 
 
 def _build_proxy_option(https_proxy: str) -> str:
@@ -67,10 +71,10 @@ def _build_proxy_option(https_proxy: str) -> str:
     return "{} ".format(" ".join(options)) if len(options) else ""
 
 
-def exec_docker(source):
+def exec_docker(source, max_days):
     base_url = get_base_url()
     os.system(
         "docker run -u $(id -u) -i --rm "
-        "-v {}:{} --env LAUNCHABLE_TOKEN {} ingest:commit -endpoint {} {}"
-        .format(source, source, ingester_image, "{}/intake/".format(base_url), source)
+        "-v {}:{} --env LAUNCHABLE_TOKEN {} ingest:commit -endpoint {} -max-days {} {}"
+        .format(source, source, ingester_image, "{}/intake/".format(base_url), max_days, source)
     )
